==> cosmo_1.0.tar.gz: cosmo/man/makeConSet.Rd <==
\name{makeConSet}
\alias{makeConSet}
\title{ Constructing a constraint set and/or group}
\description{
  The first step to building a constraint set is to define the number and type of intervals defining the set. This is done using the makeConSet
function. 
  Constraints are then built using the makeBoundCon (for information content bounding constraints), makeIntFreqCon (for interval nucleotide frequency constraints),
makePosFreqCon (for position frequency constraints) and finally makeShapeCon (for shape constraints).
  The constraints are then added to the sets created with makeConSet using the addCon command.
  Several constraint sets can then be merged using the makeConGrp to
  form a group of constraint sets.
  }
\usage{
makeConSet(numInt,type,length,descrip="Constraint Set")
}
\arguments{
  \item{numInt}{integer relating to the number of intervals composing the set}
  \item{type}{character vector describing the types of each of the intervals composing the set: the length of this vector should be equal to the 'numInt' argument.
 Possible values are 'B' for basepairs, 'V' for variable, and 'P' for proportion}
  \item{length}{numeric vector of length 'numInt', with a numeric argument describing the lengths of the intervals: either the number of basepairs if type is 'B', 
proportion coefficent if type is 'P'. For type 'V', the value is of no importance.}
  \item{descrip}{a character string to describe the constraint set or constraint group}
}
\details{
These commands are an alternative to the GUI for constucting constraint sets and groups.
}
\value{
Null.
Depending on the arguments, 1, 2 or 3 text files are created, by default in the working directory.
}
\author{
Fabian Gallusser, \email{fgallusser@berkeley.edu}, Nick Kwaan
}
\seealso{
  \code{\link{boundCon}}, \code{\link{subMotifCon}}, \code{\link{posFreqCon}}, \code{\link{shapeCon}}, \code{\link{shapeDiffCon}}, \code{\link{palCon}}
}
\examples{
makeConSet(4,c("B","P","V","B"),c(4,50,NA,3))
}
\keyword{misc}

==> cosmo_1.6.0.tar.gz: cosmo/man/makeConSet.Rd <==
\name{makeConSet}
\alias{makeConSet}
\title{ Constructing a constraint set.}
\description{
  The first step to building a constraint set is to define the number and type of intervals defining the set. This is done using the makeConSet
function. 
  Constraints are then built using the makeBoundCon (for information content bounding constraints), makeIntFreqCon (for interval nucleotide frequency constraints),
makePosFreqCon (for position frequency constraints) and finally makeShapeCon (for shape constraints).
  The constraints are then added to the sets created with makeConSet using the addCon command.
  }
\usage{
makeConSet(numInt,type,length,descrip="Constraint Set")
}
\arguments{
  \item{numInt}{integer relating to the number of intervals composing the set}
  \item{type}{character vector describing the types of each of the intervals composing the set: the length of this vector should be equal to the 'numInt' argument.
 Possible values are 'B' for basepairs, 'V' for variable, and 'P' for proportion}
  \item{length}{numeric vector of length 'numInt', with a numeric argument describing the lengths of the intervals: either the number of basepairs if type is 'B', 
proportion coefficent if type is 'P'. For type 'V', the value is of no importance.}
  \item{descrip}{a character string to describe the constraint set.}
}
\details{
These commands are an alternative to the GUI for constucting constraint sets and groups.
}
\value{
Null.
Depending on the arguments, 1, 2 or 3 text files are created, by default in the working directory.
}
\author{
Fabian Gallusser, \email{fgallusser@berkeley.edu}
}
\seealso{
  \code{\link{boundCon}}, \code{\link{subMotifCon}}, \code{\link{posFreqCon}}, \code{\link{shapeCon}}, \code{\link{shapeDiffCon}}, \code{\link{palCon}}
}
\examples{
makeConSet(4,c("B","P","V","B"),c(4,50,NA,3))
}
\keyword{misc}
